@@ -1,4 +1,4 @@
-/* $Id: browser.c 4349 2009-01-19 19:10:39Z astyanax $ */
+/* $Id: browser.c 4414 2009-10-27 04:09:27Z astyanax $ */
 /**************************************************************************
  *   browser.c                                                            *
  *                                                                        *
@@ -534,9 +534,9 @@ void browser_init(const char *path, DIR *dir)
     }
 
     /* If width isn't initialized yet, and we've taken up only one line,
-     * it means that width is equal to (COLS % longest). */
+     * it means that width is equal to longest. */
     if (width == 0)
-	width = COLS % longest;
+	width = longest;
 }
 
 /* Determine the shortcut key corresponding to the values of kbinput
