@@ -1,4 +1,4 @@
-/* $Id: chars.c 4173 2007-10-11 05:01:32Z dolorous $ */
+/* $Id: chars.c 4448 2009-11-29 06:13:22Z astyanax $ */
 /**************************************************************************
  *   chars.c                                                              *
  *                                                                        *
@@ -89,7 +89,7 @@ bool is_alnum_mbchar(const char *c)
 	wchar_t wc;
 
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = bad_wchar;
 	}
 
@@ -109,7 +109,7 @@ bool is_blank_mbchar(const char *c)
 	wchar_t wc;
 
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = bad_wchar;
 	}
 
@@ -156,7 +156,7 @@ bool is_cntrl_mbchar(const char *c)
 	wchar_t wc;
 
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = bad_wchar;
 	}
 
@@ -177,7 +177,7 @@ bool is_punct_mbchar(const char *c)
 	int c_mb_len = mbtowc(&wc, c, MB_CUR_MAX);
 
 	if (c_mb_len < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = bad_wchar;
 	}
 
@@ -243,14 +243,14 @@ char *control_mbrep(const char *c, char *crep, int *crep_len)
 	wchar_t wc;
 
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    *crep_len = bad_mbchar_len;
 	    strncpy(crep, bad_mbchar, *crep_len);
 	} else {
 	    *crep_len = wctomb(crep, control_wrep(wc));
 
 	    if (*crep_len < 0) {
-		wctomb(NULL, 0);
+		int shutup = wctomb(NULL, 0);
 		*crep_len = 0;
 	    }
 	}
@@ -278,14 +278,14 @@ char *mbrep(const char *c, char *crep, int *crep_len)
 
 	/* Reject invalid Unicode characters. */
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0 || !is_valid_unicode(wc)) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    *crep_len = bad_mbchar_len;
 	    strncpy(crep, bad_mbchar, *crep_len);
 	} else {
 	    *crep_len = wctomb(crep, wc);
 
 	    if (*crep_len < 0) {
-		wctomb(NULL, 0);
+		int shutup = wctomb(NULL, 0);
 		*crep_len = 0;
 	    }
 	}
@@ -311,7 +311,7 @@ int mbwidth(const char *c)
 	int width;
 
 	if (mbtowc(&wc, c, MB_CUR_MAX) < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = bad_wchar;
 	}
 
@@ -356,7 +356,7 @@ char *make_mbchar(long chr, int *chr_mb_len)
 
 	/* Reject invalid Unicode characters. */
 	if (*chr_mb_len < 0 || !is_valid_unicode((wchar_t)chr)) {
-	    wctomb(NULL, 0);
+	    int shutup = wctomb(NULL, 0);
 	    *chr_mb_len = 0;
 	}
     } else {
@@ -388,7 +388,7 @@ int parse_mbchar(const char *buf, char *chr, size_t *col)
 	/* If buf contains an invalid multibyte character, only
 	 * interpret buf's first byte. */
 	if (buf_mb_len < 0) {
-	    mblen(NULL, 0);
+	    int shutup = mblen(NULL, 0);
 	    buf_mb_len = 1;
 	} else if (buf_mb_len == 0)
 	    buf_mb_len++;
@@ -545,7 +545,7 @@ int mbstrncasecmp(const char *s1, const char *s2, size_t n)
 	    s1_mb_len = parse_mbchar(s1, s1_mb, NULL);
 
 	    if (mbtowc(&ws1, s1_mb, s1_mb_len) < 0) {
-		mbtowc(NULL, NULL, 0);
+		int shutup = mbtowc(NULL, NULL, 0);
 		ws1 = (unsigned char)*s1_mb;
 		bad_s1_mb = TRUE;
 	    }
@@ -553,7 +553,7 @@ int mbstrncasecmp(const char *s1, const char *s2, size_t n)
 	    s2_mb_len = parse_mbchar(s2, s2_mb, NULL);
 
 	    if (mbtowc(&ws2, s2_mb, s2_mb_len) < 0) {
-		mbtowc(NULL, NULL, 0);
+		int shutup = mbtowc(NULL, NULL, 0);
 		ws2 = (unsigned char)*s2_mb;
 		bad_s2_mb = TRUE;
 	    }
@@ -781,7 +781,7 @@ char *mbstrchr(const char *s, const char *c)
 	int c_mb_len = mbtowc(&wc, c, MB_CUR_MAX);
 
 	if (c_mb_len < 0) {
-	    mbtowc(NULL, NULL, 0);
+	    int shutup = mbtowc(NULL, NULL, 0);
 	    wc = (unsigned char)*c;
 	    bad_c_mb = TRUE;
 	}
@@ -790,7 +790,7 @@ char *mbstrchr(const char *s, const char *c)
 	    int s_mb_len = parse_mbchar(s, s_mb, NULL);
 
 	    if (mbtowc(&ws, s_mb, s_mb_len) < 0) {
-		mbtowc(NULL, NULL, 0);
+		int shutup = mbtowc(NULL, NULL, 0);
 		ws = (unsigned char)*s;
 		bad_s_mb = TRUE;
 	    }
