@@ -1,4 +1,4 @@
-/* $Id: global.c 4408 2009-09-03 23:29:14Z astyanax $ */
+/* $Id: global.c 4449 2009-11-29 06:24:10Z astyanax $ */
 /**************************************************************************
  *   global.c                                                             *
  *                                                                        *
@@ -66,6 +66,8 @@ WINDOW *bottomwin;
 	 * messages, the statusbar prompt, and a list of shortcuts. */
 int editwinrows = 0;
 	/* How many rows does the edit window take up? */
+int maxrows = 0;
+	/* How many usable lines are there (due to soft wrapping) */
 
 filestruct *cutbuffer = NULL;
 	/* The buffer where we store cut text. */
@@ -212,7 +214,7 @@ size_t length_of_list(int menu)
 }
 
 /* Set type of function based on the string */
-function_type strtokeytype(char *str)
+function_type strtokeytype(const char *str)
 {
     if (str[0] ==  'M' || str[0] == 'm')
         return META;
@@ -287,7 +289,7 @@ const sc *first_sc_for(int menu, short func) {
 
 /* Add a string to the new shortcut list implementation
    Allows updates to existing entries in the list */
-void add_to_sclist(int menu, char *scstring, short func, int toggle, int execute)
+void add_to_sclist(int menu, const char *scstring, short func, int toggle, int execute)
 {
     sc *s;
 
@@ -313,7 +315,7 @@ void add_to_sclist(int menu, char *scstring, short func, int toggle, int execute
     s->type = strtokeytype(scstring);
     s->menu = menu;
     s->toggle = toggle;
-    s->keystr = scstring;
+    s->keystr = (char *) scstring;
     s->scfunc = func;
     s->execute = execute;
     assign_keyinfo(s);
@@ -409,7 +411,10 @@ void print_sclist(void)
 
 
 /* Stuff we need to make at least static here so we can access it below */
+/* TRANSLATORS: Try to keep the next five strings at most 10 characters. */
 const char *cancel_msg = N_("Cancel");
+const char *replace_msg = N_("Replace");
+const char *no_replace_msg = N_("No Replace");
 
 #ifndef NANO_TINY
 const char *case_sens_msg = N_("Case Sens");
@@ -445,8 +450,6 @@ const char *ext_cmd_msg = "";
 /* TRANSLATORS: Try to keep the next five strings at most 10 characters. */
 const char *prev_history_msg = N_("PrevHstory");
 const char *next_history_msg = N_("NextHstory");
-const char *replace_msg = N_("Replace");
-const char *no_replace_msg = N_("No Replace");
 const char *gototext_msg = N_("Go To Text");
 /* TRANSLATORS: Try to keep the next three strings at most 12 characters. */
 const char *whereis_next_msg = N_("WhereIs Next");
@@ -488,7 +491,9 @@ void shortcut_init(bool unjustify)
     const char *fulljstify_msg = N_("FullJstify");
 #endif
     const char *refresh_msg = N_("Refresh");
+#ifndef NANO_TINY
     const char *insert_file_msg =  N_("Insert File");
+#endif
     const char *go_to_line_msg = N_("Go To Line");
 
 #ifndef DISABLE_JUSTIFY
@@ -1342,7 +1347,7 @@ const subnfunc *sctofunc(sc *s)
 #ifndef NANO_TINY
 /* Now lets come up with a single (hopefully)
    function to get a string for each flag */
-char *flagtostr(int flag)
+const char *flagtostr(int flag)
 {
    switch (flag) {
         case NO_HELP:
