@@ -1,4 +1,4 @@
-/* $Id: move.c 4408 2009-09-03 23:29:14Z astyanax $ */
+/* $Id: move.c 4444 2009-11-27 03:04:59Z astyanax $ */
 /**************************************************************************
  *   move.c                                                               *
  *                                                                        *
@@ -29,45 +29,40 @@
 /* Move to the first line of the file. */
 void do_first_line(void)
 {
-    filestruct *current_save = openfile->current;
-    size_t pww_save = openfile->placewewant;
-
-    openfile->current = openfile->fileage;
+    openfile->current = openfile->edittop = openfile->fileage;
     openfile->current_x = 0;
     openfile->placewewant = 0;
 
-    edit_redraw(current_save, pww_save);
+    edit_refresh_needed = 1;
 }
 
 /* Move to the last line of the file. */
 void do_last_line(void)
 {
-    filestruct *current_save = openfile->current;
-    size_t pww_save = openfile->placewewant;
-
     openfile->current = openfile->filebot;
     openfile->current_x = strlen(openfile->filebot->data);
     openfile->placewewant = xplustabs();
     openfile->current_y = editwinrows - 1;
 
-    edit_redraw(current_save, pww_save);
+    edit_refresh_needed = 1;
 }
 
 /* Move up one page. */
 void do_page_up(void)
 {
-    int i;
+    int i, skipped = 0;
 
     /* If there's less than a page of text left on the screen, put the
      * cursor at the beginning of the first line of the file, and then
      * update the edit window. */
-    if (openfile->current->lineno <= editwinrows - 2) {
+    if (!ISSET(SOFTWRAP) && openfile->current->lineno <= editwinrows - 2) {
 	do_first_line();
 	return;
     }
 
     /* If we're not in smooth scrolling mode, put the cursor at the
      * beginning of the top line of the edit window, as Pico does. */
+
 #ifndef NANO_TINY
     if (!ISSET(SMOOTH_SCROLL)) {
 #endif
@@ -77,15 +72,27 @@ void do_page_up(void)
     }
 #endif
 
-    for (i = editwinrows - 2; i > 0 && openfile->current !=
-	openfile->fileage; i--)
+    for (i = editwinrows - 2; i - skipped > 0 && openfile->current !=
+	openfile->fileage; i--) {
 	openfile->current = openfile->current->prev;
+	if (ISSET(SOFTWRAP) && openfile->current) {
+	    skipped += strlenpt(openfile->current->data) / COLS;
+#ifdef DEBUG
+    fprintf(stderr, "do_page_up: i = %d, skipped = %d based on line %ld len %d\n", i, (unsigned long) skipped, 
+openfile->current->lineno, strlenpt(openfile->current->data));
+#endif
+	}
+    }
 
     openfile->current_x = actual_x(openfile->current->data,
 	openfile->placewewant);
 
+#ifdef DEBUG
+    fprintf(stderr, "do_page_up: openfile->current->lineno = %lu, skipped = %d\n", (unsigned long) openfile->current->lineno, skipped);
+#endif
+
     /* Scroll the edit window up a page. */
-    edit_scroll(UP_DIR, editwinrows - 2);
+    edit_scroll(UP_DIR, editwinrows - skipped - 2);
 }
 
 /* Move down one page. */
@@ -96,7 +103,7 @@ void do_page_down(void)
     /* If there's less than a page of text left on the screen, put the
      * cursor at the beginning of the last line of the file, and then
      * update the edit window. */
-    if (openfile->current->lineno + editwinrows - 2 >=
+    if (openfile->current->lineno + maxrows - 2 >=
 	openfile->filebot->lineno) {
 	do_last_line();
 	return;
@@ -113,9 +120,14 @@ void do_page_down(void)
     }
 #endif
 
-    for (i = editwinrows - 2; i > 0 && openfile->current !=
-	openfile->filebot; i--)
+    for (i = maxrows - 2; i > 0 && openfile->current !=
+	openfile->filebot; i--) {
 	openfile->current = openfile->current->next;
+#ifdef DEBUG
+    fprintf(stderr, "do_page_down: moving to line %lu\n", (unsigned long) openfile->current->lineno);
+#endif
+
+    }
 
     openfile->current_x = actual_x(openfile->current->data,
 	openfile->placewewant);
@@ -565,17 +577,7 @@ void do_down(
 	openfile->placewewant);
 
     if (ISSET(SOFTWRAP)) {
-	filestruct *foo;
-	ssize_t extracuzsoft = 0;
-
-	for (foo = openfile->edittop; foo
-		&& foo->lineno - openfile->edittop->lineno + extracuzsoft < editwinrows;
-		foo = foo->next) {
-	    extracuzsoft += strlenpt(foo->data) / (COLS - 1);
-	    if (foo == openfile->current)
-		break;
-	}
-	if (foo && foo->lineno - openfile->edittop->lineno + extracuzsoft >= editwinrows)
+	if (openfile->current->lineno - openfile->edittop->lineno >= maxrows)
 	    onlastline = TRUE;
     }
 
