@@ -1,4 +1,4 @@
-/* $Id: nano.c 4407 2009-09-03 05:45:13Z astyanax $ */ 
+/* $Id: nano.c 4449 2009-11-29 06:24:10Z astyanax $ */ 
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -394,11 +394,7 @@ void move_to_filestruct(filestruct **file_top, filestruct **file_bot,
     /* If the top of the edit window was inside the old partition, put
      * it in range of current. */
     if (edittop_inside)
-	edit_update(
-#ifndef NANO_TINY
-		ISSET(SMOOTH_SCROLL) ? NONE :
-#endif
-		CENTER);
+	edit_update(NONE);
 
     /* Renumber starting with the beginning line of the old
      * partition. */
@@ -638,7 +634,11 @@ void die(const char *msg, ...)
 	if (filepart != NULL)
 	    unpartition_filestruct(&filepart);
 
-	die_save_file(openfile->filename);
+	die_save_file(openfile->filename
+#ifndef NANO_TINY
+		, openfile->current_stat
+#endif
+		);
     }
 
 #ifdef ENABLE_MULTIBUFFER
@@ -651,7 +651,11 @@ void die(const char *msg, ...)
 
 	    /* Save the current file buffer if it's been modified. */
 	    if (openfile->modified)
-		die_save_file(openfile->filename);
+		die_save_file(openfile->filename
+#ifndef NANO_TINY
+			, openfile->current_stat
+#endif
+			);
 	}
     }
 #endif
@@ -662,7 +666,11 @@ void die(const char *msg, ...)
 
 /* Save the current file under the name spacified in die_filename, which
  * is modified to be unique if necessary. */
-void die_save_file(const char *die_filename)
+void die_save_file(const char *die_filename
+#ifndef NANO_TINY
+	, struct stat *die_stat
+#endif
+	)
 {
     char *retval;
     bool failed = TRUE;
@@ -691,6 +699,17 @@ void die_save_file(const char *die_filename)
 	fprintf(stderr, _("\nBuffer not written: %s\n"),
 		_("Too many backup files?"));
 
+#ifndef NANO_TINY
+    /* Try and chmod/chown the save file to the values of the original file, but
+       dont worry if it fails because we're supposed to be bailing as fast
+       as possible. */
+    if (die_stat) {
+	int shush;
+	shush = chmod(retval, die_stat->st_mode);
+	shush = chown(retval, die_stat->st_uid, die_stat->st_gid);
+    }
+#endif
+
     free(retval);
 }
 
@@ -1165,11 +1184,9 @@ RETSIGTYPE do_suspend(int signal)
     disable_mouse_support();
 #endif
 
-    /* Blank the screen, and move the cursor to the last line of the
-     * screen. */
-    erase();
+    /* Move the cursor to the last line of the screen. */
     move(LINES - 1, 0);
-    refresh();
+    endwin();
 
     /* Display our helpful message. */
     printf(_("Use \"fg\" to return to nano.\n"));
@@ -1612,6 +1629,7 @@ int do_input(bool *meta_key, bool *func_key, bool *s_or_t, bool
 					&& openfile->syntax->nmultis > 0) {
 				    reset_multis(openfile->current, FALSE);
 				}
+#endif
 				if (edit_refresh_needed) {
 #ifdef DEBUG
 	    			    fprintf(stderr, "running edit_refresh() as edit_refresh_needed is true\n");
@@ -1620,7 +1638,6 @@ int do_input(bool *meta_key, bool *func_key, bool *s_or_t, bool
 				    edit_refresh_needed = FALSE;
 				}
 
-#endif
 			    }
 			}
 		    }
@@ -1667,17 +1684,53 @@ int do_mouse(void)
 
 	sameline = (mouse_y == openfile->current_y);
 
-	/* Move to where the click occurred. */
-	for (; openfile->current_y < mouse_y && openfile->current !=
-		openfile->filebot; openfile->current_y++)
-	    openfile->current = openfile->current->next;
-	for (; openfile->current_y > mouse_y && openfile->current !=
-		openfile->fileage; openfile->current_y--)
-	    openfile->current = openfile->current->prev;
+#ifdef DEBUG
+	    fprintf(stderr, "mouse_y = %d, current_y = %d\n", mouse_y, openfile->current_y);
+#endif
 
-	openfile->current_x = actual_x(openfile->current->data,
+ 	if (ISSET(SOFTWRAP)) {
+	    int i = 0;
+	    for (openfile->current = openfile->edittop;
+		 openfile->current->next && i < mouse_y;
+		 openfile->current = openfile->current->next, i++) {
+		openfile->current_y = i;
+		i += strlenpt(openfile->current->data) / COLS;
+	    }
+
+#ifdef DEBUG
+	    fprintf(stderr, "do_mouse(): moving to current_y = %d, i %d\n", openfile->current_y, i);
+	    fprintf(stderr, "            openfile->current->data = \"%s\"\n", openfile->current->data);
+#endif
+
+	    if (i > mouse_y) {
+		openfile->current = openfile->current->prev;
+		openfile->current_x = actual_x(openfile->current->data, mouse_x + (mouse_y - openfile->current_y) * COLS);
+#ifdef DEBUG
+	    fprintf(stderr, "do_mouse(): i > mouse_y, mouse_x = %d, current_x to = %d\n", mouse_x, openfile->current_x);
+#endif
+	    } else {
+	        openfile->current_x = actual_x(openfile->current->data, mouse_x);
+#ifdef DEBUG
+	    fprintf(stderr, "do_mouse(): i <= mouse_y, mouse_x = %d, setting current_x to = %d\n", mouse_x, openfile->current_x);
+#endif
+	    }
+
+	    openfile->placewewant = xplustabs();
+
+	} else {
+	    /* Move to where the click occurred. */
+	    for (; openfile->current_y < mouse_y && openfile->current !=
+		   openfile->filebot; openfile->current_y++)
+		openfile->current = openfile->current->next;
+	    for (; openfile->current_y > mouse_y && openfile->current !=
+		   openfile->fileage; openfile->current_y--)
+		openfile->current = openfile->current->prev;
+
+	    openfile->current_x = actual_x(openfile->current->data,
 		get_page_start(xplustabs()) + mouse_x);
-	openfile->placewewant = xplustabs();
+
+	    openfile->placewewant = xplustabs();
+	}
 
 #ifndef NANO_TINY
 	/* Clicking where the cursor is toggles the mark, as does
@@ -1698,7 +1751,7 @@ int do_mouse(void)
 void alloc_multidata_if_needed(filestruct *fileptr)
 {
     if (!fileptr->multidata)
-	fileptr->multidata = nmalloc(openfile->syntax->nmultis * sizeof(short));
+	fileptr->multidata = (short *) nmalloc(openfile->syntax->nmultis * sizeof(short));
 }
 
 /* Precalculate the multi-line start and end regex info so we can speed up
@@ -1737,7 +1790,7 @@ void precalc_multicolorinfo(void)
 
 
 #ifdef DEBUG
-	    fprintf(stderr, "working on lineno %zd\n", fileptr->lineno);
+	    fprintf(stderr, "working on lineno %lu\n", (unsigned long) fileptr->lineno);
 #endif
 
 		alloc_multidata_if_needed(fileptr);
@@ -1770,7 +1823,7 @@ void precalc_multicolorinfo(void)
 		    for (endptr = fileptr->next; endptr != NULL; endptr = endptr->next) {
 
 #ifdef DEBUG
-	    fprintf(stderr, "advancing to line %zd to find end...\n", endptr->lineno);
+	    fprintf(stderr, "advancing to line %lu to find end...\n", (unsigned long) endptr->lineno);
 #endif
 			/* Check for keyboard input  again */
 			if ((cur_check = time(NULL)) - last_check > 1) {
@@ -1798,18 +1851,18 @@ void precalc_multicolorinfo(void)
 			lines in between and the ends properly */
 		    fileptr->multidata[tmpcolor->id] |= CENDAFTER;
 #ifdef DEBUG
-		    fprintf(stderr, "marking line %zd as CENDAFTER\n", fileptr->lineno);
+		    fprintf(stderr, "marking line %lu as CENDAFTER\n", (unsigned long) fileptr->lineno);
 #endif
 		    for (fileptr = fileptr->next; fileptr != endptr; fileptr = fileptr->next) {
 			alloc_multidata_if_needed(fileptr);
 			fileptr->multidata[tmpcolor->id] = CWHOLELINE;
 #ifdef DEBUG
-			fprintf(stderr, "marking intermediary line %zd as CWHOLELINE\n", fileptr->lineno);
+			fprintf(stderr, "marking intermediary line %lu as CWHOLELINE\n", (unsigned long) fileptr->lineno);
 #endif
 		    }
 		    alloc_multidata_if_needed(endptr);
 #ifdef DEBUG
-		    fprintf(stderr, "marking line %zd as BEGINBEFORE\n", fileptr->lineno);
+		    fprintf(stderr, "marking line %lu as BEGINBEFORE\n", (unsigned long) fileptr->lineno);
 #endif
 		    endptr->multidata[tmpcolor->id] |= CBEGINBEFORE;
 		    /* We should be able to skip all the way to the line of the match.
@@ -1817,12 +1870,12 @@ void precalc_multicolorinfo(void)
 		    fileptr = endptr;
 		    startx = endmatch.rm_eo;
 #ifdef DEBUG
-		    fprintf(stderr, "jumping to line %zd pos %d to continue\n", endptr->lineno, startx);
+		    fprintf(stderr, "jumping to line %lu pos %d to continue\n", (unsigned long) endptr->lineno, startx);
 #endif
 		}
 		if (nostart && startx == 0) {
 #ifdef DEBUG
-		    fprintf(stderr, "no start found on line %zd, continuing\n", fileptr->lineno);
+		    fprintf(stderr, "no start found on line %lu, continuing\n", (unsigned long) fileptr->lineno);
 #endif
 		    fileptr->multidata[tmpcolor->id] = CNONE;
 		    continue;
@@ -2227,6 +2280,11 @@ int main(int argc, char **argv)
 #ifndef DISABLE_WRAPPING
 	    case 'w':
 		SET(NO_WRAP);
+
+		/* If both --fill and --nowrap are given on the command line,
+		   the last option wins, */
+		fill_used = FALSE;
+
 		break;
 #endif
 	    case 'x':
@@ -2354,6 +2412,13 @@ int main(int argc, char **argv)
 #endif
 #endif /* ENABLE_NANORC */
 
+#ifndef DISABLE_WRAPPING
+    /* Overwrite an rcfile "set nowrap" or --disable-wrapping-as-root
+       if a --fill option was given on the command line. */ 
+    if (fill_used)
+	UNSET(NO_WRAP);
+#endif
+
     /* If we're using bold text instead of reverse video text, set it up
      * now. */
     if (ISSET(BOLD_TEXT))
