@@ -1,4 +1,4 @@
-/* $Id: nano.h 4402 2009-08-17 07:52:10Z astyanax $ */
+/* $Id: nano.h 4417 2009-11-07 16:56:17Z astyanax $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
@@ -457,6 +457,7 @@ typedef struct subnfunc {
  * definitions. */
 enum
 {
+    DONTUSE,
     CASE_SENSITIVE,
     CONST_UPDATE,
     NO_HELP,
@@ -490,7 +491,7 @@ enum
     BOLD_TEXT,
     QUIET,
     UNDOABLE,
-    SOFTWRAP,
+    SOFTWRAP
 };
 
 /* Flags for which menus in which a given function should be present */
