@@ -1,4 +1,4 @@
-/* $Id: prompt.c 4349 2009-01-19 19:10:39Z astyanax $ */
+/* $Id: prompt.c 4448 2009-11-29 06:13:22Z astyanax $ */
 /**************************************************************************
  *   prompt.c                                                             *
  *                                                                        *
@@ -868,7 +868,7 @@ void update_statusbar_line(const char *curranswer, size_t index)
     free(expanded);
 
     wattroff(bottomwin, reverse_attr);
-
+    statusbar_pww = statusbar_xplustabs();
     reset_statusbar_cursor();
     wnoutrefresh(bottomwin);
 }
@@ -956,7 +956,7 @@ const sc *get_prompt_string(int *actual, bool allow_tabs,
     currmenu = menu;
 
 #ifdef DEBUG
-fprintf(stderr, "get_prompt_string: answer = \"%s\", statusbar_x = %d\n", answer, statusbar_x);
+fprintf(stderr, "get_prompt_string: answer = \"%s\", statusbar_x = %lu\n", answer, (unsigned long) statusbar_x);
 #endif
 
     update_statusbar_line(answer, statusbar_x);
@@ -1070,7 +1070,6 @@ fprintf(stderr, "get_prompt_string: answer = \"%s\", statusbar_x = %d\n", answer
 		}
 	} else
 #endif /* !NANO_TINY */
-#ifndef DISABLE_HELP
 	if (s && s->scfunc == DO_HELP_VOID) {
 		update_statusbar_line(answer, statusbar_x);
 
@@ -1082,7 +1081,6 @@ fprintf(stderr, "get_prompt_string: answer = \"%s\", statusbar_x = %d\n", answer
 		 * prompt. */
 		finished = FALSE;
 	}
-#endif
 
 	/* If we have a shortcut with an associated function, break out
 	 * if we're finished after running or trying to run the
