@@ -1,4 +1,4 @@
-/* $Id: rcfile.c 4402 2009-08-17 07:52:10Z astyanax $ */
+/* $Id: rcfile.c 4445 2009-11-27 05:09:56Z astyanax $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -89,7 +89,7 @@ static const rcoption rcopts[] = {
     {"smarthome", SMART_HOME},
     {"smooth", SMOOTH_SCROLL},
     {"tabstospaces", TABS_TO_SPACES},
-    {"undo", 0},
+    {"undo", UNDOABLE},
     {"whitespace", 0},
     {"wordbounds", WORD_BOUNDS},
     {"softwrap", SOFTWRAP},
@@ -454,7 +454,6 @@ void parse_keybinding(char *ptr)
 	return;
     }
 
-
     /* now let's have some fun.  Try and delete the other entries
        we found for the same menu, then make this new new
        beginning */
@@ -470,6 +469,70 @@ void parse_keybinding(char *ptr)
     sclist = newsc;
 }
 
+/* Let user unbind a sequence from a given (or all) menus */
+void parse_unbinding(char *ptr)
+{
+    char *keyptr = NULL, *keycopy = NULL, *menuptr = NULL;
+    sc *s;
+    int i, menu;
+
+    assert(ptr != NULL);
+
+    if (*ptr == '\0') {
+	rcfile_error(N_("Missing key name"));
+	return;
+    }
+
+    keyptr = ptr;
+    ptr = parse_next_word(ptr);
+    keycopy = mallocstrcpy(NULL, keyptr);
+    for (i = 0; i < strlen(keycopy); i++)
+	keycopy[i] = toupper(keycopy[i]);
+
+#ifdef DEBUG
+    fprintf(stderr, "Starting unbinding code");
+#endif
+
+    if (keycopy[0] != 'M' && keycopy[0] != '^' && keycopy[0] != 'F' && keycopy[0] != 'K') {
+	rcfile_error(
+		N_("keybindings must begin with \"^\", \"M\", or \"F\""));
+	return;
+    }
+
+    menuptr = ptr;
+    ptr = parse_next_word(ptr);
+
+    if (!strcmp(menuptr, "")) {
+	rcfile_error(
+		/* Note to translators, do not translate the word "all"
+		   in the sentence below, everything else is fine */
+		N_("Must specify menu to bind key to (or \"all\")"));
+	return;
+    }
+
+    menu = strtomenu(menuptr);
+    if (menu < 1) {
+	rcfile_error(
+		N_("Could not map name \"%s\" to a menu"), menuptr);
+	return;
+    }
+
+
+#ifdef DEBUG
+    fprintf(stderr, "unbinding \"%s\" from menu = %d\n", keycopy, menu);
+#endif
+
+    /* Now find the apropriate entries in the menu to delete */
+    for (s = sclist; s != NULL; s = s->next) {
+        if (((s->menu & menu)) && !strcmp(s->keystr,keycopy)) {
+	    s->menu &= ~menu;
+#ifdef DEBUG
+	    fprintf(stderr, "deleted menu entry %d\n", s->menu);
+#endif
+	}
+    }
+}
+
 
 /* Read and parse additional syntax files. */
 void parse_include(char *ptr)
@@ -829,7 +892,7 @@ void parse_rcfile(FILE *rcstream
 {
     char *buf = NULL;
     ssize_t len;
-    size_t n;
+    size_t n = 0;
 
     while ((len = getline(&buf, &n, rcstream)) > 0) {
 	char *ptr, *keyword, *option;
@@ -895,6 +958,8 @@ void parse_rcfile(FILE *rcstream
 	    parse_colors(ptr, TRUE);
 	else if (strcasecmp(keyword, "bind") == 0)
 	    parse_keybinding(ptr);
+	else if (strcasecmp(keyword, "unbind") == 0)
+	    parse_unbinding(ptr);
 #endif /* ENABLE_COLOR */
 	else
 	    rcfile_error(N_("Command \"%s\" not understood"), keyword);
@@ -1047,6 +1112,9 @@ void parse_rcfile(FILE *rcstream
 		else
 		    rcfile_error(N_("Cannot unset flag \"%s\""),
 			rcopts[i].name);
+		/* Looks like we still need this specific hack for undo */
+		if (strcasecmp(rcopts[i].name, "undo") == 0)
+		    shortcut_init(0);
 		break;
 	    }
 	}
