@@ -1,4 +1,4 @@
-/* $Id: text.c 4407 2009-09-03 05:45:13Z astyanax $ */ 
+/* $Id: text.c 4448 2009-11-29 06:13:22Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -181,7 +181,7 @@ void do_tab(void)
 	free(output);
     } else {
 #endif
-	do_output("\t", 1, TRUE);
+	do_output((char *) "\t", 1, TRUE);
 #ifndef NANO_TINY
     }
 #endif
@@ -409,7 +409,7 @@ void redo_cut(undo *u) {
 	for (c = u->cutbuffer, t = openfile->current; c->next != NULL && t->next != NULL; ) {
 
 #ifdef DEBUG
-	fprintf(stderr, "Advancing, lineno  = %zd, data = \"%s\"\n", t->lineno, t->data);
+	fprintf(stderr, "Advancing, lineno  = %lu, data = \"%s\"\n", (unsigned long) t->lineno, t->data);
 #endif
 	    c = c->next;
 	    t = t->next;
@@ -483,7 +483,7 @@ void do_undo(void)
 	break;
     case SPLIT:
 	undidmsg = _("line wrap");
-	f->data = nrealloc(f->data, strlen(f->data) + strlen(u->strdata) + 1);
+	f->data = (char *) nrealloc(f->data, strlen(f->data) + strlen(u->strdata) + 1);
 	strcpy(&f->data[strlen(f->data) - 1], u->strdata);
 	if (u->strdata2 != NULL)
 	    f->next->data = mallocstrcpy(f->next->data, u->strdata2);
@@ -517,7 +517,7 @@ void do_undo(void)
 	undidmsg = _("line break");
 	if (f->next) {
 	    filestruct *foo = f->next;
-	    f->data = nrealloc(f->data, strlen(f->data) + strlen(f->next->data) + 1);
+	    f->data = (char *) nrealloc(f->data, strlen(f->data) + strlen(f->next->data) + 1);
 	    strcat(f->data,  f->next->data);
 	    unlink_node(foo);
 	    delete_node(foo);
@@ -765,7 +765,7 @@ bool execute_command(const char *command)
      * arguments. */
     shellenv = getenv("SHELL");
     if (shellenv == NULL)
-	shellenv = "/bin/sh";
+	shellenv = (char *) "/bin/sh";
 
     /* Fork a child. */
     if ((pid = fork()) == 0) {
@@ -859,7 +859,7 @@ void add_undo(undo_type current_action)
     }
 
     /* Allocate and initialize a new undo type */
-    u = nmalloc(sizeof(undo));
+    u = (undo *) nmalloc(sizeof(undo));
     u->type = current_action;
     u->lineno = fs->current->lineno;
     u->begin = fs->current_x;
@@ -943,8 +943,8 @@ void add_undo(undo_type current_action)
     }
 
 #ifdef DEBUG
-    fprintf(stderr, "fs->current->data = \"%s\", current_x = %zd, u->begin = %d, type = %d\n",
-			fs->current->data,  fs->current_x, u->begin, current_action);
+    fprintf(stderr, "fs->current->data = \"%s\", current_x = %lu, u->begin = %d, type = %d\n",
+			fs->current->data,  (unsigned long) fs->current_x, u->begin, current_action);
     fprintf(stderr, "left add_undo...\n");
 #endif
     fs->last_action = current_action;
@@ -966,10 +966,10 @@ void update_undo(undo_type action)
 	return;
 
 #ifdef DEBUG
-        fprintf(stderr, "action = %d, fs->last_action = %d,  openfile->current->lineno = %zd",
-		action, fs->last_action, openfile->current->lineno);
+        fprintf(stderr, "action = %d, fs->last_action = %d,  openfile->current->lineno = %lu",
+		action, fs->last_action, (unsigned long) openfile->current->lineno);
 	if (fs->current_undo)
-	    fprintf(stderr, "fs->current_undo->lineno = %zd\n",  fs->current_undo->lineno);
+	    fprintf(stderr, "fs->current_undo->lineno = %lu\n",  (unsigned long) fs->current_undo->lineno);
 	else
 	    fprintf(stderr, "\n");
 #endif
@@ -989,11 +989,11 @@ void update_undo(undo_type action)
     switch (u->type) {
     case ADD:
 #ifdef DEBUG
-        fprintf(stderr, "fs->current->data = \"%s\", current_x = %zd, u->begin = %d\n",
-			fs->current->data,  fs->current_x, u->begin);
+        fprintf(stderr, "fs->current->data = \"%s\", current_x = %lu, u->begin = %d\n",
+			fs->current->data, (unsigned long) fs->current_x, u->begin);
 #endif
         len = strlen(u->strdata) + 2;
-        data = nrealloc((void *) u->strdata, len * sizeof(char *));
+        data = (char *) nrealloc((void *) u->strdata, len * sizeof(char *));
         data[len-2] = fs->current->data[fs->current_x];
         data[len-1] = '\0';
         u->strdata = (char *) data;
