@@ -1,4 +1,4 @@
-/* $Id: utils.c 4361 2009-02-01 00:04:42Z astyanax $ */
+/* $Id: utils.c 4372 2009-02-08 17:45:21Z astyanax $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -542,6 +542,9 @@ void new_magicline(void)
     openfile->filebot->next->prev = openfile->filebot;
     openfile->filebot->next->next = NULL;
     openfile->filebot->next->lineno = openfile->filebot->lineno + 1;
+#ifdef ENABLE_COLOR
+    openfile->filebot->next->multidata = NULL;
+#endif
     openfile->filebot = openfile->filebot->next;
     openfile->totsize++;
 }
